#
# spec file for package hotspot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hotspot
Version:        1.5.1
Release:        1.3
Summary:        Perf GUI for performance analysis
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            https://github.com/KDAB/hotspot
Source:         https://github.com/KDAB/hotspot/releases/download/v%{version}/hotspot-v%{version}.tar.gz
Source1:        https://github.com/KDAB/hotspot/releases/download/v%{version}/hotspot-perfparser-v%{version}.tar.gz
Source2:        https://github.com/KDAB/hotspot/releases/download/v%{version}/hotspot-PrefixTickLabels-v%{version}.tar.gz
BuildRequires:  extra-cmake-modules
%if 0%{?suse_version} == 1500
BuildRequires:  gcc13-c++
BuildRequires:  gcc13-PIE
%endif
BuildRequires:  glibc-devel-static
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  libzstd-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KDDockWidgets)
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5ItemModels)
BuildRequires:  cmake(KF5ItemViews)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5SyntaxHighlighting)
BuildRequires:  cmake(KF5ThreadWeaver)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
# qcustomplot-devel in Leap 15 needs this dependency. Keep it there for the moment
%if 0%{?suse_version} == 1500
BuildRequires:  cmake(Qt5PrintSupport)
%endif
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(libdebuginfod)
BuildRequires:  pkgconfig(qcustomplot)
Requires:       binutils
Requires:       perf
Requires:       pkexec

%description
Hotspot is a standalone GUI for performance data with an UI like KCachegrind
around Linux perf.

%prep
# %%autosetup fails with more than one extra 'Source'
%setup -q -n %{name} -a 1 -a 2

mv perfparser/* 3rdparty/perfparser/
mv PrefixTickLabels/* 3rdparty/PrefixTickLabels/

%build
%if 0%{?suse_version} == 1500
export CXX=g++-13
%endif

%cmake_kf5 -d build

%install
%kf5_makeinstall -C build

%files
%license LICENSE.GPL.txt
%doc README.md
%{_kf5_applicationsdir}/com.kdab.hotspot.desktop
%{_kf5_appstreamdir}/com.kdab.Hotspot.appdata.xml
%{_kf5_bindir}/hotspot
%if %{pkg_vcmp kf5-filesystem >= 20220307}
%{_libexecdir}/hotspot-perfparser
%else
%{_kf5_libdir}/libexec/hotspot-perfparser
%endif
%{_kf5_iconsdir}/hicolor/*/*/hotspot.png
%{_kf5_notifydir}/hotspot.notifyrc

%changelog
* Tue May 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.5.1
  Features:
  * add tab width setting
  Bug Fixes:
  * add a wrapper for std::valarray to catch out of range
    access
  * can't select directory in unwind->sysroot
  * clear flamegraph background in 5.15.12
  * crash in disassembler on hover
  * don't show ansi escape sequences in tooltip
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.5.0
  https://github.com/KDAB/hotspot/releases/tag/v1.5.0
  * code cleanups, bug fixes and new functionalities
- Drop patch, no longer needed:
  * 0001-Opt-in-via-CMake-to-allow-privilege-escalation.patch
* Wed Dec 27 2023 Antonio Larrosa <alarrosa@suse.com>
- Add BuildRequires extra-cmake-modules and cmake(KF5Archive) to
  fix a build failure.
* Tue Mar 14 2023 Christophe Marin <christophe@krop.fr>
- Replace 0001-Prevent-running-hotspot-as-root.patch with
  upstream change (boo#1209206, CVE-2023-28144):
  * 0001-Opt-in-via-CMake-to-allow-privilege-escalation.patch
* Wed Mar  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.4.1:
  * improved disassembly view with a godbolt-like source code
    annotation
  * the self cost columns for tracepoints are now hidden by default
  * more flexible window layouting with KDDockWidgets
  * you can export and import data from hotspot in a custom
    format that is efficient to load and self-contained
  * analysis data can be grouped by thread, process or CPU
  * demangling for the D programming language
  * a new frequency page that shows how often certain events got
    measured, which can also indicate the CPU frequency scaling
    when cycles are measured
- Drop patch, merged upstream:
  * 0001-CMake-Don-t-assume-KDE_INSTALL_-variables-are-relati.patch
- Add patch to prevent running hotspot as root (boo#1208808)
  * 0001-Prevent-running-hotspot-as-root.patch
* Thu May 12 2022 Lubos Lunak <l.lunak@centrum.cz>
- Enable zstd support.
* Sun Mar 20 2022 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup.
- Use %%_libexec where needed.
- Add patch:
  * 0001-CMake-Don-t-assume-KDE_INSTALL_-variables-are-relati.patch
* Thu Sep  3 2020 Markus Ebner <info@ebner-markus.de>
- Update to 1.3.0
  * Unable to widen "Symbol" column in Top Down view
  * Feature Request: Support gksu for "Profile System" in AppImage
  * better formatting of times and trace costs in flamegraph and tooltips
  * fix time formatting
  * Loading a trace is much slower in 1.2 than in 1.1
  * Perfparser exits with code 1 (TCP Socket error) when opening a perf.data file
  * feature: open editor on function
  * group threads by process
  * android simpleperf support
  * Timeline part takes too much space
  * Profile system is broken
  * README required dependencies (QT5) out of date with master branch cmake
  * proper rust symbol demangling
  * enable rust demangling for appimages
  * Perfparser/Hotspot cannot unwind the stack for fork() of created processes
  * feature: auto-expand bottom-up tree
* Fri Jul 26 2019 Markus Ebner <info@ebner-markus.de>
- Update to 1.2.0
  * Adds quite a few bug fixes
  * Performance improvements
  * Addition of a per-CPU core event timeline
  * Events can now be filtered by symbols
  * Hotspot can now be used to analyze off-CPU time
* Wed Jul 18 2018 alarrosa@suse.com
- Initial version of hotspot 1.1.0
